"use strict";
var tslib_1 = require("tslib");
var core_1 = require("@angular/core");
var common = require("./common");
var NodeComponent = (function () {
    function NodeComponent() {
        this.toggle = new core_1.EventEmitter();
        this.change = new core_1.EventEmitter();
        this.hovered = false;
        this.doubleClick = new common.DoubleClick();
    }
    Object.defineProperty(NodeComponent.prototype, "nodeClassName", {
        get: function () {
            return common.getNodeClassName(this.data, this.last);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "anchorClassName", {
        get: function () {
            return common.getAnchorClassName(this.data, this.hovered);
        },
        enumerable: true,
        configurable: true
    });
    NodeComponent.prototype.hover = function (hovered) {
        this.hovered = hovered;
    };
    NodeComponent.prototype.ontoggle = function (eventData) {
        if (eventData) {
            this.toggle.emit(eventData);
        }
        else {
            if (this.data.children && this.data.children.length > 0) {
                this.toggle.emit({ data: this.data });
            }
        }
    };
    NodeComponent.prototype.onchange = function (eventData) {
        var _this = this;
        if (eventData) {
            this.change.emit(eventData);
        }
        else {
            if (this.data.state.disabled) {
                return;
            }
            this.doubleClick.onclick(function () {
                _this.change.emit({ data: _this.data });
            });
        }
    };
    return NodeComponent;
}());
tslib_1.__decorate([
    core_1.Input()
], NodeComponent.prototype, "data", void 0);
tslib_1.__decorate([
    core_1.Input()
], NodeComponent.prototype, "last", void 0);
tslib_1.__decorate([
    core_1.Output()
], NodeComponent.prototype, "toggle", void 0);
tslib_1.__decorate([
    core_1.Output()
], NodeComponent.prototype, "change", void 0);
NodeComponent = tslib_1.__decorate([
    core_1.Component({
        selector: "node",
        template: "\n    <li role=\"treeitem\" [class]=\"nodeClassName\">\n        <i class=\"jstree-icon jstree-ocl\" role=\"presentation\" (click)=\"ontoggle()\"></i><a [class]=\"anchorClassName\" href=\"javascript:void(0)\" (click)=\"onchange()\" (dblclick)=\"ontoggle()\" (mouseenter)=\"hover(true)\" (mouseleave)=\"hover(false)\"><i class=\"jstree-icon jstree-themeicon\" role=\"presentation\"></i>{{data.text}}</a>\n        <ul *ngIf=\"data.children\" role=\"group\" class=\"jstree-children\">\n            <node *ngFor=\"let child of data.children; let i = index\"\n                [data]=\"child\"\n                [last]=\"i === data.children.length - 1\"\n                (toggle)=\"ontoggle($event)\"\n                (change)=\"onchange($event)\">\n            </node>\n        </ul>\n    </li>\n    ",
    })
], NodeComponent);
exports.NodeComponent = NodeComponent;
var TreeComponent = (function () {
    function TreeComponent() {
        this.toggle = new core_1.EventEmitter();
        this.change = new core_1.EventEmitter();
    }
    TreeComponent.prototype.ontoggle = function (eventData) {
        this.toggle.emit(eventData);
    };
    TreeComponent.prototype.onchange = function (eventData) {
        this.change.emit(eventData);
    };
    return TreeComponent;
}());
tslib_1.__decorate([
    core_1.Input()
], TreeComponent.prototype, "data", void 0);
tslib_1.__decorate([
    core_1.Output()
], TreeComponent.prototype, "toggle", void 0);
tslib_1.__decorate([
    core_1.Output()
], TreeComponent.prototype, "change", void 0);
TreeComponent = tslib_1.__decorate([
    core_1.Component({
        selector: "tree",
        template: "\n    <div class=\"jstree jstree-default jstree-default-dark\" role=\"tree\">\n        <ul class=\"jstree-container-ul jstree-children\" role=\"group\">\n            <node *ngFor=\"let child of data; let i = index\"\n                [data]=\"child\"\n                [last]=\"i === data.length - 1\"\n                (toggle)=\"ontoggle($event)\"\n                (change)=\"onchange($event)\"></node>\n        </ul>\n    </div>\n    ",
    })
], TreeComponent);
exports.TreeComponent = TreeComponent;
//# sourceMappingURL=angular.js.map